@@ -50,7 +50,11 @@ class Handler(object):
             sys.exit(0)
 
     def read_event(self):
-        self.event = utils.read_event()
+        evt = utils.read_event()
+        if evt.has_key('event'):
+            self.event = evt.get('event')
+        else:
+            self.event = evt
 
     def handle(self):
         raise HandlerException('No handle functionality defined')
